GpioRequest

Enum GpioRequest 

pub enum GpioRequest {
    Read {
        responder: GpioReadResponder,
    },
    SetBufferMode {
        mode: BufferMode,
        responder: GpioSetBufferModeResponder,
    },
    GetInterrupt {
        options: InterruptOptions,
        responder: GpioGetInterruptResponder,
    },
    ConfigureInterrupt {
        config: InterruptConfiguration,
        responder: GpioConfigureInterruptResponder,
    },
    ReleaseInterrupt {
        responder: GpioReleaseInterruptResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: GpioControlHandle, method_type: MethodType, }, }
Common error codes:

  • ZX_ERR_NOT_SUPPORTED: The requested operation is not supported by this controller.

Variants



Read

Reads the current value of a GPIO, returning true for a high voltage and false for a low voltage.

Fields



SetBufferMode

Configures the output buffer as per mode.



GetInterrupt

Gets an interrupt object pertaining to a particular GPIO pin. Only one interrupt may be outstanding per pin, and it must be released by calling ReleaseInterrupt() before the next call to GetInterrupt() will succeed. The interrupt is unmasked prior to being returned to the caller.

Returns ZX_ERR_ALREADY_EXISTS if GetInterrupt() has already been called without a subsequent call to ReleaseInterrupt(), ZX_ERR_INVALID_ARGS if options is invalid, or ZX_ERR_ACCESS_DENIED if another client has the interrupt.



ConfigureInterrupt

Configures the polarity of an interrupt and whether it is edge- or level-triggered. Only the client with the interrupt can call ConfigureInterrupt(), unless no client has an interrupt.

Returns ZX_ERR_INVALID_ARGS if no fields are set in config, or ZX_ERR_ACCESS_DENIED if another client has the interrupt.



ReleaseInterrupt

Releases the interrupt, allowing GetInterrupt() to be called again or by another client. A client’s interrupt is automatically released when it disconnects from the server. The interrupt is masked upon release.

Returns ZX_ERR_NOT_FOUND if the interrupt has already been released, or if GetInterrupt() has not been called. Returns ZX_ERR_ACCESS_DENIED if another client has the interrupt.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

control_handle: GpioControlHandle
method_type: MethodType

Implementations