pub struct GpioGetInterruptResponse {
pub interrupt: Interrupt,
}Fields
interrupt: InterruptTrait Implementations
Sourceimpl Debug for GpioGetInterruptResponse
impl Debug for GpioGetInterruptResponse
Sourceimpl Decode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for GpioGetInterruptResponse
impl Decode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for GpioGetInterruptResponse
Sourceimpl Encode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for &mut GpioGetInterruptResponse
impl Encode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for &mut GpioGetInterruptResponse
Sourceimpl<T0: Encode<HandleType<Interrupt, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<Interrupt, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<GpioGetInterruptResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for GpioGetInterruptResponse
impl Hash for GpioGetInterruptResponse
Sourceimpl Ord for GpioGetInterruptResponse
impl Ord for GpioGetInterruptResponse
Sourcefn cmp(&self, other: &GpioGetInterruptResponse) -> Ordering
fn cmp(&self, other: &GpioGetInterruptResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioGetInterruptResponse
impl PartialEq for GpioGetInterruptResponse
Sourcefn eq(&self, other: &GpioGetInterruptResponse) -> bool
fn eq(&self, other: &GpioGetInterruptResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioGetInterruptResponse
impl PartialOrd for GpioGetInterruptResponse
Sourceimpl ResourceTypeMarker for GpioGetInterruptResponse
impl ResourceTypeMarker for GpioGetInterruptResponse
Sourcetype Borrowed<'a> = &'a mut GpioGetInterruptResponse
type Borrowed<'a> = &'a mut GpioGetInterruptResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for GpioGetInterruptResponse
impl TypeMarker for GpioGetInterruptResponse
Sourcetype Owned = GpioGetInterruptResponse
type Owned = GpioGetInterruptResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for GpioGetInterruptResponse
impl Standalone<DefaultFuchsiaResourceDialect> for GpioGetInterruptResponse
impl StructuralPartialEq for GpioGetInterruptResponse