pub struct GpioMarker;Trait Implementations
Sourceimpl Clone for GpioMarker
impl Clone for GpioMarker
Sourcefn clone(&self) -> GpioMarker
fn clone(&self) -> GpioMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GpioMarker
impl Debug for GpioMarker
Sourceimpl Hash for GpioMarker
impl Hash for GpioMarker
Sourceimpl Ord for GpioMarker
impl Ord for GpioMarker
Sourcefn cmp(&self, other: &GpioMarker) -> Ordering
fn cmp(&self, other: &GpioMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioMarker
impl PartialEq for GpioMarker
Sourcefn eq(&self, other: &GpioMarker) -> bool
fn eq(&self, other: &GpioMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioMarker
impl PartialOrd for GpioMarker
Sourceimpl ProtocolMarker for GpioMarker
impl ProtocolMarker for GpioMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) Gpio"
const DEBUG_NAME: &'static str = "(anonymous) Gpio"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = GpioProxy
type Proxy = GpioProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = GpioRequestStream
type RequestStream = GpioRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = GpioSynchronousProxy
type SynchronousProxy = GpioSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for GpioMarker
impl Eq for GpioMarker
impl StructuralPartialEq for GpioMarker